# frozen_string_literal: true

# rubocop:disable Metrics/BlockLength

require 'human_size'

RSpec.describe HumanSize do
    it 'has a version number' do
        expect(HumanSize::VERSION).not_to be nil
    end

    context 'Class Accessor Method' do
        before(:each) do
            @hs = HumanSize::Size
        end

        context 'Binary (1024 bytes per Megabyte)) mode' do
            it 'says unknown for bytes < 0' do
                expect(@hs.human_size(-1)).to eql('unknown')
            end

            it 'says 0.0 B for 0 bytes' do
                expect(@hs.human_size(0)).to eql('0.0 B')
            end

            it 'says 941.9 MiB for 987654321 bytes' do
                expect(@hs.human_size(987_654_321)).to eql('941.9 MiB')
            end
        end

        context 'SI (1000 bytes per Megabyte) mode' do
            it 'says unknown for bytes < 0' do
                expect(@hs.human_size(-1, false)).to eql('unknown')
            end

            it 'says 0.0 B for 0 bytes' do
                expect(@hs.human_size(0, false)).to eql('0.0 B')
            end

            it 'says 987.7 MB for 987654321 bytes' do
                expect(@hs.human_size(987_654_321, false)).to eql('987.7 MB')
            end
        end
    end

    context 'String Accessor Method' do
        context 'Binary (1024 bytes per Megabyte)) mode' do
            it 'says unknown for bytes < 0' do
                expect(-1.human_size).to eql('unknown')
            end

            it 'says 0.0 B for 0 bytes' do
                expect(0.human_size).to eql('0.0 B')
            end

            it 'says 941.9 MiB for 987654321 bytes' do
                expect(987_654_321.human_size).to eql('941.9 MiB')
            end
        end

        context 'SI (1000 bytes per Megabyte)) mode' do
            it 'says unknown for bytes < 0' do
                expect(-1.human_size(false)).to eql('unknown')
            end

            it 'says 0.0 B for 0 bytes' do
                expect(0.human_size(false)).to eql('0.0 B')
            end

            it 'says 987.7 MB for 987654321 bytes' do
                expect(987_654_321.human_size(false)).to eql('987.7 MB')
            end
        end
    end
end

# rubocop:enable Metrics/BlockLength
